##
##  horcrux.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2023 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
%define       V_horcrux_base  0.2
%define       V_horcrux_snap  20230917

#   package information
Name:         horcrux
Summary:      Encrypted File Split/Bind
URL:          https://github.com/jesseduffield/horcrux
Vendor:       Jesse Duffield
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Cryptography
License:      MIT
Version:      %{V_horcrux_base}.%{V_horcrux_snap}
Release:      20230917

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/horcrux/horcrux-%{V_horcrux_snap}.tar.xz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, go
PreReq:       OpenPKG, openpkg >= 20160101

%description
    Horcrux splits a file into encrypted fragments so that you don't
    need to remember a passcode. It uses Shamir Secret Sharing Scheme
    (SSSS) under the hood.

%track
    prog horcrux = {
        version   = %{V_horcrux_base}
        url       = https://github.com/jesseduffield/horcrux/releases
        regex     = tree/v(\d+\.\d+(?:\.\d+)?)
    }

%prep
    %setup -q -n horcrux

%build
    #   build program
    (   export GOPATH=`pwd`
        cd $GOPATH/src/github.com/jesseduffield/horcrux
        go build -v -o horcrux main.go
    ) || exit $?

%install
    #   create directory hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin

    #   install program
    %{l_shtool} install -c -s -m 755 \
        src/github.com/jesseduffield/horcrux/horcrux \
        $RPM_BUILD_ROOT%{l_prefix}/bin/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

